package ar.edu.unju.fi.lambda;

import java.util.*;
import java.util.stream.Collectors;

public class MainProducto {
    public static void main(String[] args) {
        // Crear una lista de 10 productos
        List<Producto> productos = Arrays.asList(
                new Producto(1, "Producto A", 10.50),
                new Producto(2, "Producto B", 23.75),
                new Producto(3, "Producto C", 8.99),
                new Producto(4, "Producto D", 45.00),
                new Producto(5, "Producto E", 12.30),
                new Producto(6, "Producto F", 30.00),
                new Producto(7, "Producto G", 22.40),
                new Producto(8, "Producto H", 9.99),
                new Producto(9, "Producto I", 40.00),
                new Producto(10, "Producto J", 5.50)
        );

        // Mostrar la lista de productos
        System.out.println("Lista de productos:");
        productos.forEach(System.out::println);

        // Filtrar productos cuyo precio es mayor a 20
        List<Producto> productosMayorA20 = productos.stream()
                .filter(p -> p.getPrecio() > 20)
                .collect(Collectors.toList());
        System.out.println("\nProductos con precio mayor a 20:");
        productosMayorA20.forEach(System.out::println);

        // Buscar un producto por descripción
        String descripcionBuscada = "Producto C";
        Optional<Producto> productoBuscado = productos.stream()
                .filter(p -> p.getDescripcion().equalsIgnoreCase(descripcionBuscada))
                .findFirst();
        System.out.println("\nProducto encontrado con descripción '" + descripcionBuscada + "':");
        productoBuscado.ifPresent(System.out::println);

        // Ordenar la lista de productos por precio ascendente
        List<Producto> productosOrdenadosPorPrecio = productos.stream()
                .sorted(Comparator.comparingDouble(Producto::getPrecio))
                .collect(Collectors.toList());
        System.out.println("\nProductos ordenados por precio (ascendente):");
        productosOrdenadosPorPrecio.forEach(System.out::println);

        // Obtener el producto con el precio máximo
        Producto productoMasCaro = productos.stream()
                .max(Comparator.comparingDouble(Producto::getPrecio))
                .orElseThrow();
        System.out.println("\nProducto con el precio más alto:");
        System.out.println(productoMasCaro);

        // Obtener la suma total de los precios de todos los productos
        double sumaTotalPrecios = productos.stream()
                .mapToDouble(Producto::getPrecio)
                .sum();
        System.out.println("\nSuma total de los precios de los productos: " + sumaTotalPrecios);

        // Obtener productos cuyo precio es mayor que el promedio de los precios
        double promedioPrecio = productos.stream()
                .mapToDouble(Producto::getPrecio)
                .average()
                .orElse(0);
        List<Producto> productosMayorQuePromedio = productos.stream()
                .filter(p -> p.getPrecio() > promedioPrecio)
                .collect(Collectors.toList());
        System.out.println("\nProductos con precio mayor al promedio (" + promedioPrecio + "):");
        productosMayorQuePromedio.forEach(System.out::println);
    }
}
