package ar.edu.unju.fi.lambda;

import java.util.List;
import java.util.Random;
import java.util.stream.Collectors;

/**
 * Operaciones básicas con una lista de enteros
 * @author jzapana
 */
public class StreamListBasic {
    public static void main(String[] args) {
        // Generar una lista de 10 números enteros aleatorios
        List<Integer> randomNumbers = new Random().ints(10, 0, 100)
                .boxed()
                .collect(Collectors.toList());

        // Mostrar la lista generada
        System.out.println("Lista generada: " + randomNumbers);

        // Sumar todos los elementos de la lista
        int sum = randomNumbers.stream().mapToInt(Integer::intValue).sum();
        System.out.println("Suma: " + sum);

        // Calcular el promedio de los elementos
        double average = randomNumbers.stream().mapToInt(Integer::intValue).average().orElse(0);
        System.out.println("Promedio: " + average);

        // Encontrar el valor máximo
        int max = randomNumbers.stream().max(Integer::compare).orElseThrow();
        System.out.println("Máximo: " + max);

        // Encontrar el valor mínimo
        int min = randomNumbers.stream().min(Integer::compare).orElseThrow();
        System.out.println("Mínimo: " + min);

        // Filtrar números mayores a 50 y mostrarlos
        List<Integer> filteredNumbers = randomNumbers.stream()
                .filter(n -> n > 50)
                .collect(Collectors.toList());
        System.out.println("Números mayores a 50: " + filteredNumbers);

        // Multiplicar cada número por 2 y mostrar la lista resultante
        List<Integer> doubledNumbers = randomNumbers.stream()
                .map(n -> n * 2)
                .collect(Collectors.toList());
        System.out.println("Números multiplicados por 2: " + doubledNumbers);

        // Contar cuántos números son pares
        long countEvens = randomNumbers.stream()
                .filter(n -> n % 2 == 0)
                .count();
        System.out.println("Cantidad de números pares: " + countEvens);

    }
}
