package ar.edu.unju.fi.lambda;
import java.util.Comparator;
import java.util.List;
import java.util.Random;
import java.util.stream.Collectors;

/**
 * Operaciones con listas donde el resultado es otra lista
 * @author jzapana
 */
public class StreamListOperations {
    public static void main(String[] args) {
        // Generar una lista de 20 números enteros aleatorios
        List<Integer> randomNumbers = new Random().ints(10, 0, 100)
                .boxed()
                .collect(Collectors.toList());

        // Mostrar la lista generada
        System.out.println("Lista generada: " + randomNumbers);

        // Filtrar números mayores a 50
        List<Integer> numbersGreaterThan50 = randomNumbers.stream()
                .filter(n -> n > 50)
                .collect(Collectors.toList());
        System.out.println("Números mayores a 50: " + numbersGreaterThan50);

        // Ordenar la lista en orden ascendente
        List<Integer> sortedNumbersAsc = randomNumbers.stream()
                .sorted()
                .collect(Collectors.toList());
        System.out.println("Lista ordenada de menor a mayor: " + sortedNumbersAsc);

        // Ordenar la lista en orden descendente
        List<Integer> sortedNumbersDesc = randomNumbers.stream()
                .sorted(Comparator.reverseOrder())
                .collect(Collectors.toList());
        System.out.println("Lista ordenada de mayor a menor: " + sortedNumbersDesc);

        // Calcular el promedio de los números
        double average = randomNumbers.stream().mapToInt(Integer::intValue).average().orElse(0);
        System.out.println("Promedio: " + average);

        // Filtrar números mayores al promedio
        List<Integer> numbersGreaterThanAverage = randomNumbers.stream()
                .filter(n -> n > average)
                .collect(Collectors.toList());
        System.out.println("Números mayores al promedio: " + numbersGreaterThanAverage);

        // Obtener los primeros 5 números de la lista (luego de ordenar)
        List<Integer> first5Numbers = randomNumbers.stream()
                .sorted()
                .limit(5)
                .collect(Collectors.toList());
        System.out.println("Primeros 5 números de la lista ordenada: " + first5Numbers);

        // Eliminar duplicados y devolver una lista con números únicos
        List<Integer> uniqueNumbers = randomNumbers.stream()
                .distinct()
                .collect(Collectors.toList());
        System.out.println("Números únicos (sin duplicados): " + uniqueNumbers);

        //Calcular la suma de todos los números, reduce devuelve un solo resultado.
        //la variable a es auxiliar y se inicia en cero.
        System.out.println("Suma de todos los números: "+ randomNumbers.stream().reduce((a,b)-> a+b).get());
    }
}
